pub struct SessionLogger { /* private fields */ }Expand description
Session-aware logger that wraps tracing spans
Creates a tracing span with session context fields and provides convenient methods for logging with session information.
Implementations
Sourceimpl SessionLogger
impl SessionLogger
Sourcepub fn new(context: SessionContext) -> Self
pub fn new(context: SessionContext) -> Self
Create a new session logger
This creates a tracing span at INFO level with all session context fields.
Arguments
context- The session context
Example
use rusmes_server::session_logging::{SessionContext, SessionLogger};
use std::net::IpAddr;
let session = SessionContext::new(
IpAddr::from([127, 0, 0, 1]),
"IMAP",
);
let logger = SessionLogger::new(session);Sourcepub fn enter(&self) -> Entered<'_>
pub fn enter(&self) -> Entered<'_>
Enter the session span
Returns a guard that will exit the span when dropped. All logging done while the guard is held will include session context.
Example
use rusmes_server::session_logging::{SessionContext, SessionLogger};
use std::net::IpAddr;
let session = SessionContext::new(
IpAddr::from([127, 0, 0, 1]),
"POP3",
);
let logger = SessionLogger::new(session);
let _guard = logger.enter();
tracing::info!("This log will include session context");Sourcepub fn context(&self) -> &SessionContext
pub fn context(&self) -> &SessionContext
Get the session context
Sourcepub fn set_username(&mut self, username: impl Into<String>)
pub fn set_username(&mut self, username: impl Into<String>)
Update the session context with a username
This creates a new span with the updated username field.
Arguments
username- The authenticated username